消失的爱人 (豆瓣)
Description: 消失的爱人电影简介和剧情介绍,消失的爱人影评、图片、预告片、影讯、论坛、在线购票
Keywords: 消失的爱人,Gone Girl,消失的爱人影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.122豆瓣电影Top250

# 消失的爱人 Gone Girl (2014)

导演: 大卫·芬奇
编剧: 吉莉恩·弗林
主演: 本·阿弗莱克 / 裴淳华 / 尼尔·帕特里克·哈里斯 / 凯莉·库恩 / 泰勒·派瑞 / 金·迪肯斯 / 米西·派勒 / 波伊德·霍布鲁克 / 艾米丽·拉塔科斯基 / 雪拉·渥德 / 派屈克·福吉特 / 斯科特·麦克纳里 / 凯西·威尔逊 / 李·诺里斯
类型: 剧情 / 悬疑 / 惊悚 / 犯罪
制片国家/地区: 美国
语言: 英语
上映日期: 2014-09-26(纽约电影节) / 2014-10-03(美国)
片长: 149分钟
又名: 失踪的女孩 / 失踪女孩 / 失踪罪(港) / 控制(台)
IMDb: tt2267998
豆瓣评分
引用
8.7
883579人评价
5星
47.8%
4星
42.7%
3星
8.7%
2星
0.6%
1星
0.2%
好于 98% 悬疑片
好于 98% 犯罪片
想看 看过
评价:
推荐

## 消失的爱人的剧情简介 · · · · · ·

结婚五周年纪念日的早上，尼克·邓恩（本·阿弗莱克 Ben Affleck 饰）来到妹妹玛戈（凯莉·库恩 Carrie Coon 饰）的酒吧，咒骂抱怨那个曾经彼此恩爱缠绵的妻子艾米（罗莎蒙德·派克 Rosamund Pike 饰）以及全然看不见希望的婚姻。当他返回家中时， 却发现客厅留下了暴行的痕迹，而妻子竟不见了踪影。女探员朗达·邦妮（金·迪肯斯 Kim Dickens 饰）接到报案后赶来调查，而现场留下的种种蛛丝马迹似乎昭示着这并非是一件寻常的失踪案，其背后或许隐藏着裂变于夫妻之情的谋杀罪行。艾米的失踪通过媒体大肆渲染和妄加揣测很快闻名全国，品行不端的尼克被推上风口浪尖，至今不见踪影的爱人对他进行无情审判，你侬我侬的甜言蜜语早已化作以血洗血的复仇与折磨……
本片根据吉莉安·弗琳（Gillian Flynn）的同名小说改编。 ©豆瓣

## 消失的爱人的演职员 · · · · · · ( 全部 35 )

- 大卫·芬奇 导演
- 本·阿弗莱克 饰 Nick Dunne
- 裴淳华 饰 Amy Dunne
- 尼尔·帕特里克·哈里斯 饰 Desi Collings
- 凯莉·库恩 饰 Margo Dunne
- 泰勒·派瑞 饰 Tanner Bolt

## 消失的爱人的视频和图片 ······ ( 预告片10 | 视频评论1 · 添加 | 图片1617 · 添加 )

## 消失的爱人的获奖情况 · · · · · · ( 全部 )

- 第87届奥斯卡金像奖
- 最佳女主角(提名)
- 裴淳华

- 第72届金球奖
- 电影类 最佳导演(提名)
- 大卫·芬奇

- 第35届金酸莓奖
- 最佳赎莓奖
- 本·阿弗莱克

## 喜欢这部电影的人也喜欢 · · · · · ·

  看不见的客人

  禁闭岛

  记忆碎片

  致命ID

  七宗罪

  控方证人

  恐怖游轮

  杀人回忆

  沉默的羔羊

  利刃出鞘

我要写短评

## 消失的爱人的短评 · · · · · · ( 全部 232951 条 )

热门 / 最新 / 好友

### 6235 有用 猫司令 看过 2014-10-10 09:54:51

唯一令我不解的是，聪明绝顶的女主为什么不好好跟长得像马云的富二代在一块儿，而要回到那呆傻的丈夫身边呢？就因为看了会儿电视？

### 17204 有用 朝阳区陆依萍 看过 2015-01-02 21:17:49

相信我...其实，这就是马伊琍和文章的故事...

### 9585 有用 二千 看过 2014-10-02 00:49:14

男：我们互相折磨，互相控制，这样有什么意义呢？ 女：这就是婚姻。

### 5777 有用 芦哲峰 看过 2014-12-16 09:33:39

爱人不见了，千夫所指。爱人回来了，万丈深渊；婚姻是一袭华美的袍，这是面子。爬满了虱子，这是里子。

### 4900 有用 L'automne 看过 2014-10-04 22:15:13

后半段我一直期待有更惊喜的东西，可惜没有。

> 更多短评 232951条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 消失的爱人的影评 · · · · · · ( 全部 2588 条 )

热门 / 最新 / 好友
爱幻想的小孩 2014-10-05 02:38:18

## 冷峻的魅力

这篇影评可能有剧透

这年头影评写的都和剧情梗概似的，大部分笔墨都在分析故事，这固然没什么不好。但Gone Girl会是一部让你有冲动写真正“影评”的电影，因为从电影制作的角度来讲，各个方面都耀眼到不能让人忽视。 选角和表演 有很多导演表示过，“Directing is 80 percent casting.” 意思是... (展开)
7565 394 283回应 收起
September 2014-12-12 09:12:09

## Cool Girl和Gone girl之间的距离，叫做婚姻

小说和电影都看过。小说因为文本的关系，在人物的挖掘方面更深度一些。但电影在有限的篇幅里也漂亮地叙述了一个一波三折的故事，层层递进环环相扣。作为一部情节曲折猎奇的片子，其中的一些概念很有意思，特别是小说里的心理描写对这些概念延伸拓展，对婚姻和爱情提出了许多挑... (展开)
5616 278 294回应 收起
与三 2014-10-16 19:43:28

## 与其说在黑婚姻，不如说在黑中产精英

当然首先黑的还是婚姻，或者是在探讨婚姻在现代后工业社会中的意义。 如果说人际间交往都会不可避免的走向权利竞争，导致他人即地狱的局面，那么组建家庭后，一方或者双方不愿意切实履行生育的义务和责任，成员对婚姻本质的理解即将陷入困境。 问题的焦点在于，有什么理由能让... (展开)
4307 227 303回应 收起
林愈静 2015-02-02 13:03:02

## 人闲是非多

有几天经常看到陈赫离婚的消息，在任何可能看到的地方。现在，我已是个成熟的人，对陈赫一无所知，也没去Google。好多强迫我看的消息，新闻，电影，电视，就这么过滤了。人生苦短，在信息爆炸时代，信息取舍上，我已经学会了断舍离。而且是完全自然的那种，简言之，已经成佛。... (展开)
1066 168 182回应 收起
朽木立夏警部殿 2014-12-14 21:25:54

## 病蔷薇

《消失的爱人》是一部很酷的电影，不仅仅因为AMY如魔女嘉莉一般浑身鲜血，以胜利者的姿态浴火重生，完成了又一次新的假人格塑造；比这更奇妙的是，AMY这个角色激发出了观众心中的恶。我必须得承认，在观赏电影的过程中，不止一次地在心中为这个心理扭曲的碧池摇旗呐喊。直到她... (展开)
831 49 76回应 收起
小斑 2014-10-22 04:45:01

## 芬奇老湿从良了

消失的电梯http://movie.douban.com/review/7157647/?start=100#comments 《超感神探》里有一集抓SK。馒头叔给FBI的证据就是「你看过他洗手间的柜子（一丝不苟的整齐）么？他一定是变态杀手」。 写这集的剧本师傅才适合来改这本小说（顺便说我觉得馒头叔多适合演Colins的！）... (展开)
532 134 177回应 收起
frankerstein 2014-12-27 23:04:38

## 说说我打两星的原因

这篇影评可能有剧透

看到好多给五星四星的，以及’冷峻’、’深刻’的评价。说说我为啥打两星。首先必须说明，无论大家怎么喷，两星是看完’全片’之后的诚实感受。之所以强调全片，是因为电影的开头是很棒的，4星甚至5星的确不过分。实际上，个人认为前1/3都很好，一直到揭穿整个失踪事件是妻子的... (展开)
732 286 186回应 收起
perceptor 2014-10-07 00:42:31

## 我没有结过婚你不要吓我

这篇影评可能有剧透

这是一则关于婚姻的现代寓言。关于婚姻，这个故事中的表象仍是亘古不变的围城和坟墓的困局，激情到日常，幻想到破灭，相爱到冷漠到怨恨到相杀。新媒体引导下的公众舆论为这则故事披上了现代性的外衣，但对于长期浸淫在美国文化中的观众而言，公众群体无意识和易被操纵的本性也... (展开)
346 47 57回应 收起
Leo 2014-10-12 12:24:51

## 非常好的观影体验（纯影评+个人感受——媒体、婚姻、女性社会角色）

在结婚周年纪念日这天，Affleck演的Nick发现妻子Amy不见了，警察来了，媒体来了，全城都轰动了，后来全国人都议论了起来，这就是电影Gone Girl的剧情基础。 Gone Girl 原著电子书，一读就停不下来了。 无剧透。 -----------------------------------------------------------... (展开)
173 22 20回应 收起
盐lynn 2014-10-23 21:12:13

## 让我们选择一场表演

艾米和尼克相识于纽约的一场文化派对。尼克是来自南部的杂志撰稿人，艾米是心理题的写手，土生土长的纽约客，因其父母曾出了一套“小魔女艾米”漫画风靡全美，身家富贵。两人迅速相爱然后结婚，却经历了双双失业和破产，回到了尼克老家密西西比州。一年多后，艾米突然失踪，尼... (展开)
130 17 5回应 收起

> 更多影评 2588篇

添加新讨论

## 讨论区 · · · · · ·

我看到一半的时候就猜到律师就是男孩他妈 | 来自小小鱼 | 231 回应 | 2022-11-24 21:28:49
我想知道为什么女主宁愿搭上自己也要报复男主？以... | 来自许墨菲 | 12 回应 | 2022-11-23 19:26:36
男猪脚那二奶的身材碉堡了，导演应该多给她裸露加戏份 | 来自奔向耶路撒冷 | 46 回应 | 2022-11-21 11:09:30
关于影片现行多种删减版本和时长的疑问 | 来自七年前封笔Vae | 6 回应 | 2022-11-19 11:06:41
女主很正常，男人还是不懂得珍惜 | 来自清歌 | 222 回应 | 2022-11-16 23:11:34

> 去这部影片的讨论区（全部377条）

## 关于《消失的爱人》的问题 · · · · · · ( 全部283个 )

- 記者發佈會拍照的時候男主爲什麼要笑？ 37人回答
- 有个小bug。。。。。？ 51人回答

> 全部283个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 他们是高智商玩家 (中间元素)
- {北美电影票房总排行} (荔枝超人)
- 【坚强的女性】 (影志)

## 谁在看这部电影 · · · · · ·

- wrnxnn
  3分钟前 看过
- whcwhcwhc
  3分钟前 看过
- 喂在干嘛呢
  7分钟前 看过

1229835人看过 / 371794人想看

订阅消失的爱人的评论:
feed: rss 2.0